@@ -472,7 +472,7 @@ class tree:
             cell = np.arange(0,len(pts),dtype=np.int_)
             cell = np.insert(cell,0,len(pts))
             poly.lines = cell
-            poly.scalars = r/r[0]
+            poly['radius'] = r
             return poly
         interp_xyz,interp_r,interp_xyzr = self.export(make=False)
         vessels = []
@@ -487,7 +487,8 @@ class tree:
             points[:,1] = y
             points[:,2] = z
             polyline = polyline_from_points(points,r)
-            vessel = polyline.tube(radius=r[0])
+            vessel = polyline.tube(radius=min(r),scalars='radius',radius_factor=max(r)/min(r)).triangulate()
+            #vessel = polyline.tube(radius=r[0])
             vessels.append(vessel)
             vessel_fix = pymeshfix.MeshFix(remesh_surface(vessel.triangulate(),hausd=0.001,verbosity=0))
             vessel_fix.repair(verbose=False)
